@@ -6,7 +6,7 @@ App::Mypp - Maintain Your Perl Project
 
 =head1 VERSION
 
-0.04
+0.05
 
 =head1 DESCRIPTION
 
@@ -48,6 +48,9 @@ anything, so 1) it just works 2) it might not work as you want it to.
  -makefile
   * Create a Makefile.PL from plain guesswork
 
+ -version
+  * Display the version number for for mypp
+
  -man
   * Display manual for mypp
 
@@ -121,7 +124,7 @@ use File::Basename;
 use File::Find;
 use YAML::Tiny;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 our $SILENT = $ENV{'SILENT'} || 0;
 our $MAKEFILE_FILENAME = 'Makefile.PL';
 our $CHANGES_FILENAME = 'Changes';
@@ -567,24 +570,24 @@ sub _pm_requires {
             push @modules, $module if(caller(0) eq $required_module);
         }, @INC);
 
-        require $file or warn $@;
+        eval "use $required_module (); 1" or warn $@;
         return if($@);
     }
 
     if(my $meta = eval "$required_module\->meta") {
         if($meta->isa('Class::MOP::Class')) {
-            push @modules, $meta->superclasses, map { $_->name } @{ $meta->roles };
+            push @modules, $meta->superclasses, map { split /\|/, $_->name } @{ $meta->roles };
         }
         else {
-            push @modules, map { $_->name } @{ $meta->get_roles };
+            push @modules, map { split /\|/, $_->name } @{ $meta->get_roles };
         }
     }
     else {
         push @modules, eval "\@$required_module\::ISA";
     }
 
-    for my $module (@modules) {
-        my $version = $self->_version_from_module($module) or next;
+    for my $m (@modules) {
+        my($module, $version) = $self->_version_from_module($m) or next;
         $requires->{$module} = $version;
     }
 
@@ -619,10 +622,10 @@ sub _script_requires {
         }
     }
 
-    for my $module (@$modules) {
+    for my $m (@$modules) {
         local $SIG{'__WARN__'} = sub { print $_[0] unless($_[0] =~ /\sredefined\sat/)};
-        eval "require $module";
-        my $version = $self->_version_from_module($module) or next;
+        eval "use $m (); 1" or warn $@;
+        my($module, $version) = $self->_version_from_module($m) or next;
         $requires->{$module} = $version;
     }
 
@@ -843,11 +846,13 @@ sub _version_from_module {
     my $module = shift;
 
     while($module) {
-        return $_ if($_ = eval "\$$module\::VERSION");
+        if(my $version = eval "\$$module\::VERSION") {
+            return($module, $version);
+        }
         $module =~ s/::\w+$// or last;
     }
 
-    return 0;
+    return;
 }
 
 =head1 SEE ALSO
